Timed events documentation — Poezio 0.9-dev documentation

# Timed events documentation

Timed events are the standard way to schedule events for later in poezio.

Once created, they must be added to the list of checked events with `Core.add_timed_event()` (within poezio) or with `PluginAPI.add_timed_event()` (within a plugin).

class `timed_events.` `TimedEvent`(date, callback, *args)

  An event with a callback that is called when the specified time is passed.

  The callback and its arguments should be passed as the lasts arguments.

  `__init__`(date, callback, *args)

    Create a new timed event.

    Parameters: | date (datetime.datetime) – Time at which the callback must be run. callback (function) – The handler that will be executed. *args – Optional arguments passed to the handler.

class `timed_events.` `DelayedEvent`(delay, callback, *args)

  A TimedEvent, but with the date calculated from now + a delay in seconds. Use it if you want an event to happen in, e.g. 6 seconds.

  `__init__`(delay, callback, *args)

    Create a new DelayedEvent.

    Parameters: | delay (int) – The number of seconds. callback (function) – The handler that will be executed. *args – Optional arguments passed to the handler.